@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
 #ifndef DISPAREA_H
 #define DISPAREA_H
 
-#include "geocpp/geometry.h"
+#include <geocpp/geocpp.h>
 
 
 /** A generic display area
@@ -33,13 +33,6 @@ public:
     CDispArea(real izoom = 0.8);
 
     CRect3d calcLRect(const CRect3d &viewRect, const CRect3d &objRect);
-    /** Get the current zoom factor. */
-    real getZoom()
-    {
-        return zoom;
-    }
-
-
 
 protected:
     /** The center of the viewing area, in logical coordinates */
