@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,22 +22,18 @@
 
 #include <QMainWindow>
 #include <QMessageBox>
+#include <QMenu>
 #include <QUrl>
-
-#include "sailcalc.h"
-
-#include "sail.h"
-#include "saildef.h"
+#include "formdocument.h"
 
 // forward definitions
-class QApplication;
-class QMenuBar;
-class QGridLayout;
+class QAction;
 class QMenu;
+class QMenuBar;
 class QStatusBar;
-class QTabWidget;
-class QTranslator;
-class CSailViewerPanel;
+class QWorkspace;
+class QSignalMapper;
+
 class CPrefs;
 class CSailApp;
 
@@ -53,18 +49,18 @@ public:
     CFormMain(CSailApp *myApp, QWidget *parent = 0);
 
     void show(const QString newname = QString::null);
-    void setSailDef(const CSailDef newdef);
 
 protected:
     void closeEvent( QCloseEvent * e);
-    void keyPressEvent ( QKeyEvent * e );
     void makeMenuMru();
-    void fileAccess(QString event, QString file);
+    void open(QString filename);
 
+private:
+    void addChild(CFormDocument *child);
     void setupMenuBar();
     void setupMainWidget();
+    CFormDocument *activeChild();
 
-    // slots
 protected slots:
 
     virtual void languageChange();
@@ -72,75 +68,48 @@ protected slots:
     virtual void slotAbout();
     virtual void slotAboutQt();
 
-    virtual void slotDef();
-    virtual void slotExportDXF();
-    virtual void slotExportTXT();
-    virtual void slotExportXML();
-    virtual void slotExportFlatCarlson();
-    virtual void slotExportFlatDXF();
-    virtual void slotExportFlatDXFBlocks();
-    virtual void slotExportFlatHand();
-    virtual void slotExportFlatTXT();
-    virtual void slotExportFlatXML();
-    virtual void slotMould();
     virtual void slotNew();
     virtual void slotOpen();
     virtual void slotOpenRecent();
-    virtual void slotRig();
     virtual void slotSave();
     virtual void slotSaveAs();
 
-    virtual void slotPrintData();
-    virtual void slotPrintDwg();
-    virtual void slotPrintDev();
-
     virtual void slotHandbook();
 
     virtual void slotLanguage();
+    virtual void slotUpdateDocumentMenus();
+    virtual void slotUpdateWindowMenu();
 
-    // member variables
 protected:
+    /** the workspace */
+    QWorkspace *workspace;
+
+    /** signal mapper */
+    QSignalMapper *windowMapper;
+
     /** the location of the Sailcut CAD Handbook */
     QUrl handbook;
 
     /** the application */
     CSailApp *app;
+
     /** the user preferences */
     CPrefs *prefs;
 
-    /** the widgets of each view */
-    vector<CSailViewerPanel *> panel;
-    /** the tab widget */
-    QTabWidget *tabs;
-
     /** the status bar */
     QStatusBar* statusbar;
 
-    /** the definition of the current sail */
-    CSailDef saildef;
-    /** the sail */
-    CSail sail;
-    /** the developped sail */
-    CSail flatsail;
-    /** the display version of the flat sail */
-    CSail dispsail;
-    /** the current filename */
-    QString filename;
-
-    // menus and action
     /** the File menu */
     QMenu *menuFile;
-    /** the Print submenu */
-    QMenu *menuPrint;
-    /** the Export 3d submenu */
-    QMenu *menuExport3d;
-    /** the Export flat submenu */
-    QMenu *menuExportFlat;
+    /** the New submenu */
+    QMenu *menuFileNew;
     /** the Help menu */
     QMenu *menuHelp;
     /** the View menu */
     QMenu *menuView;
-    /** the language submenu */
+    /** the Window menu */
+    QMenu *menuWindow;
+    /** the Language menu */
     QMenu *menuLanguage;
 
     /** the Most Recently Used files menu */
@@ -150,40 +119,32 @@ protected:
     QAction *actionAbout;
     /** display information about Qt */
     QAction *actionAboutQt;
+    /** close the active document */
+    QAction *actionClose;
+    /** close all documents */
+    QAction *actionCloseAll;
+    /** tile document windows */
+    QAction *actionTile;
+    /** cascade document windows */
+    QAction *actionCascade;
     /** display the handbook */
     QAction *actionHandbook;
+    /** create a new boat */
+    QAction *actionNewBoat;
+    /** create a new hull */
+    QAction *actionNewHull;
+    /** create a new rig */
+    QAction *actionNewRig;
     /** create a new sail */
-    QAction *actionNew;
+    QAction *actionNewSail;
     /** open an existing sail definition */
     QAction *actionOpen;
     /** sail the sail definition to a file */
     QAction *actionSave;
     /** prompt for a filename then write the sail definition to a file */
     QAction *actionSaveAs;
-    /** export 3D sail to DXF */
-    QAction *actionExport3dDXF;
-    /** export 3D sail to text */
-    QAction *actionExport3dTXT;
-    /** export 3D sail to XML */
-    QAction *actionExport3dXML;
-    /** export flat sail to Carlson plotter format */
-    QAction *actionExportFlatCarlson;
-    /** export flat sail to hand format */
-    QAction *actionExportFlatHand;
-    /** export flat sail to DXF format */
-    QAction *actionExportFlatDXF;
-    /** export flat sail to DXF blocks format */
-    QAction *actionExportFlatDXFBlocks;
-    /** export flat sail to TXT format */
-    QAction *actionExportFlatTXT;
-    /** export flat sail to XML format */
-    QAction *actionExportFlatXML;
-    /** print sail data */
-    QAction *actionPrintData;
-    /** print sail development */
-    QAction *actionPrintDev;
-    /** print sail drawing */
-    QAction *actionPrintDwg;
+    /** final separator in the 'File' menu before 'Quit' */
+    QAction *actionFileSep;
     /** view sail definition */
     QAction *actionViewDef;
     /** view sail mould */
@@ -192,8 +153,15 @@ protected:
     QAction *actionViewPatch;
     /** view sail rig */
     QAction *actionViewRig;
+    /** separator in the 'Window' menu */
+    QAction *actionWindowSep;
     /** quit */
     QAction *actionQuit;
+
+    /** extra actions for the file menu */
+    vector<QAction*> childFileActions;
+    /** extra actions for the view menu */
+    vector<QAction*> childViewActions;
 };
 
 #endif
