@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,9 +23,7 @@
 #include <vector>
 #include <QString>
 
-#include "geocpp/geometry.h"
-#include "geocpp/subspace.h"
-#include "geocpp/matrix.h"
+#include <geocpp/geocpp.h>
 
 enum enumPointType { LUFF, FOOT, LEECH, GAFF };
 enum enumAlign {LEFT, LOW_LEFT, BOTTOM};
@@ -173,6 +171,7 @@ public:
     void addHems( const real &, const real &, const real &, const real &);
     CPanel develop(enumDevelopAlign align) const;
     real height() const;    //  height Y of a panel
+    
     void placeLabel();   //  place a label at the center of a panel
     CPanel reframe(enumAlign align) const;
     CPanel rotate( const CPoint3d &, const CMatrix &) const;
