@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -53,8 +53,7 @@ void CPrefsMru::touchEntry( const QString &newEntry )
  * Constructs a class holding the user's preferences.
  */
 CPrefs::CPrefs() :
-        helpWindowWidth(600), helpWindowHeight(500),
-        rigWindowWidth(700), rigWindowHeight(700),
-        sailWindowWidth(800), sailWindowHeight(600)
+        helpWindowWidth(800), helpWindowHeight(600),
+        mainWindowWidth(800), mainWindowHeight(600)
 {}
 
