@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -48,25 +48,19 @@ class CPrefs
 public:
     CPrefs();
 
-    /** The most recently used rig definitions. */
-    CPrefsMru mruRigdef;
-    /** The most recently used sail definitions. */
-    CPrefsMru mruSaildef;
+    /** The most recently used documents. */
+    CPrefsMru mruDocuments;
 
     /** The width of the help window */
     int helpWindowWidth;
     /** The height of the help window */
     int helpWindowHeight;
+    
+    /** The width of the main window */
+    int mainWindowWidth;
+    /** The height of the main window */
+    int mainWindowHeight;
 
-    /** The width of the rig window */
-    int rigWindowWidth;
-    /** The height of the rig window */
-    int rigWindowHeight;
-
-    /** The width of the sail window */
-    int sailWindowWidth;
-    /** The height of the sail window */
-    int sailWindowHeight;
     /** The preferred language. */
     QString language;
 };
