@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,11 +20,15 @@
 #ifndef SAILCALC_H
 #define SAILCALC_H
 
-#include "geocpp/geometry.h"
+#include <geocpp/geocpp.h>
 
+/* computation of parabolic edge round */
 real RoundP( const real &x, const int &p );
+/* computation of angle of triangle defined by 3 sides */
 real Atriangle( const real &a, const real &b, const real &c );
+/* computation of angle of triangle defined by 3 points */
 real Atriangle3d ( const CPoint3d &pta, const CPoint3d &ptb, const CPoint3d &ptc );
+/* computation of distance of a point to a line defined by 2 points */
 real Distance3d(const CPoint3d &pta, const CPoint3d &ptb, const CPoint3d &ptc);
 
 #endif
