@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -22,7 +22,6 @@
 #include <QDir>
 #include <QTranslator>
 #include <QUrl>
-#include "sailreader-xml.h"
 #include "sailwriter-xml.h"
 
 using namespace std;
@@ -33,7 +32,7 @@ using namespace std;
  * @param argc
  * @param argv
  */
-CSailApp::CSailApp(int argc, char* argv[]) :
+CSailApp::CSailApp(int &argc, char** argv) :
         QApplication(argc, argv)
 {
     // create and install translators
@@ -61,11 +60,12 @@ QUrl CSailApp::findHandbook(const QString locale)
 #endif
 
     // look for handbook in different languages
+    QDir appDir(applicationDirPath());
     for (int i = 0; i < locales.size(); i++)
     {
         for (int d = 0; d < docdirs.size(); d++)
         {
-            handbook = docdirs.at(d) + QDir::separator() + locales.at(i) + QDir::separator() + "index.html";
+            handbook = appDir.absoluteFilePath(docdirs.at(d) + QDir::separator() + locales.at(i) + QDir::separator() + "index.html");
             if (QFile::exists(handbook))
                 return QUrl::fromLocalFile(QFileInfo(handbook).absoluteFilePath());
         }
@@ -93,8 +93,9 @@ void CSailApp::loadTranslation(const QString locale)
 #endif
 
     int d = 0;
+    QDir appDir(applicationDirPath());
     while ((d < datadirs.size()) &&
-            (!transApp->load(qm, datadirs.at(d))))
+            (!transApp->load(qm, appDir.absoluteFilePath(datadirs.at(d)))))
     {
         d++;
     }
@@ -110,11 +111,11 @@ void CSailApp::readPrefs()
     try
     {
         if (QFile(prefsfile).exists())
-            prefs = CPrefsXmlReader("prefs").read(prefsfile);
+            prefs = CPrefsXmlWriter().read(prefsfile);
     }
     catch (CException e)
     {
-        qDebug("Could not read preferences");
+        cout << "CSailApp::readPrefs : could not read preferences" << endl;
     }
 }
 
@@ -126,10 +127,10 @@ void CSailApp::writePrefs()
 {
     try
     {
-        CPrefsXmlWriter(prefs,"prefs").write(prefsfile);
+        CPrefsXmlWriter().write(prefs, prefsfile);
     }
     catch (CException e)
     {
-        qDebug("Could not write preferences");
+        cout << "CSailApp::writePrefs : could not write preferences" << endl;
     }
 }
