@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -38,7 +38,7 @@ class QUrl;
 class CSailApp : public QApplication
 {
 public:
-    CSailApp(int argc, char* argv[]);
+    CSailApp(int &argc, char** argv);
 
     static QUrl findHandbook(const QString locale);
     void loadTranslation(const QString locale);
