@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -26,7 +26,8 @@
  
 **************************************************************************/
 
-/** Constructs a CSailDef object.
+/** Constructs a CSailDef object from the default sail parameters.
+ *
  */
 CSailDef::CSailDef()
 {
@@ -35,21 +36,21 @@ CSailDef::CSailDef()
     sailCut = CROSS;
     sailID = "Test sail 1";
 
-    LOA    = 7000;  // length of hull in millimetre
+    LOA    = 7000;   // length of hull in millimetre
     foreJ  = 2000;    // base of fore triangle
-    foreI  = 5500;    // height of fore triangle
+    foreI  = 6500;    // height of fore triangle
 
-    tackX  = 2100;  // longitudinal distance of main sail tack from stem in millimetre
-    tackY  = 400;    // height of sail tack above stem in millimetre
+    tackX  = 1972;    // longitudinal distance of main sail tack from stem in millimetre
+    tackY  = 750;     // height of sail tack above stem in millimetre
     luffL  = 6250;    // in millimetre
-    rake   = 200;     // in millimetre
+    rake   = 161;     // in millimetre
     gaffDeg= 45;     // in degree
     gaffL  = 2500;   // in millimetre
-    leechL = 8220;  // in millimetre
+    leechL = 8220;   // in millimetre
     footL  = 4100;   // in millimetre
 
-    luffR  = 10;       // in millimetre // NOTE: Positive value for mast bend Negative for headstay sag
-    luffRP = 45;      // in percent of luff length
+    luffR  = 67;     // in millimetre // NOTE: Positive value for mast bend Negative for headstay sag
+    luffRP = 50;      // in percent of luff length
     gaffR  = 150;    // in millimetre
     gaffRP = 50;     // in percent
     leechR = -120;  // in millimetre // NOTE: Negative value for hollow leech
@@ -70,7 +71,6 @@ CSailDef::CSailDef()
     nbSections = 5;      // radial sections
     nbGores = 5;         // radial gores
     nbLuffGores = 2;   // luff gores
-
 }
 
 
@@ -89,10 +89,8 @@ CSailDef::CSailDef()
 CSailDef & CSailDef::operator=( const CSailDef &copy )
 {
     if (&copy == this)
-    {
-        CException e("CSailDef::operator= : self-assignment!");
-        throw(e);
-    }
+        return *this;
+    // else
     sailID = copy.sailID;
     sailCut = copy.sailCut;
     sailType = copy.sailType;
