@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 #include <QString>
 
 #include "sailmould.h"
-#include "geocpp/subspace.h"
 
 
 // enumerated types
@@ -31,9 +30,10 @@ enum enumSailType { MAINSAIL, JIB, WING };
 enum enumSailCut { CROSS, TWIST, HORIZONTAL, VERTICAL, RADIAL, MITRE };
 
 
-/** This class holds the parameters that define a sail.
+/** This class holds the parameters that define a sail
+ *  and the default parameters
  *
- * @see CSailWorker, CSail
+ *  @see CFormSailDef for data input and checking, CSailWorker
  */
 class CSailDef
 {
