@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -31,17 +31,16 @@ CSailDisp::CSailDisp()
 {
     // initialise data
     m = CMatrix::id(3);
-    //setSail(sail);
     drawLabels = false;
-    zoom=0.8;
+    zoom = 0.8;
 }
 
 
-/** Rotates local copy of the sail by a given azimuth and elevation.
+/** Rotates local copy of the object by a given azimuth and elevation.
  */
-void CSailDisp::calcSailDisp()
+void CSailDisp::calcDispObject()
 {
-    sailDisp = sailBase.rotate( rectBase.center(), m);
+    dispObject = baseObject.rotate( baseRect.center(), m );
 }
 
 
@@ -49,9 +48,9 @@ void CSailDisp::calcSailDisp()
  */
 void CSailDisp::resetZoomCenter()
 {
-    center=CPoint3d(0,0,0);
+    center = baseRect.center();
     zoom = 0.8;
-    calcLRect(m_vRect, rectBase);
+    logicalRect = calcLRect(viewRect, baseRect);
 }
 
 
@@ -60,11 +59,11 @@ void CSailDisp::resetZoomCenter()
 CPoint3d CSailDisp::screenToLogical( const int x, const int y ) const
 {
     // avoid division by zero
-    if ((m_vRect.width()==0)||(m_vRect.height()==0))
+    if ((viewRect.width()==0)||(viewRect.height()==0))
         return center;
 
-    return center + CVector3d( m_lRect.width() * ( real(x) / m_vRect.width() - 0.5 ),
-                               m_lRect.height() * ( 0.5 - real(y) / m_vRect.height() ), 0);
+    return center + CVector3d( logicalRect.width() * ( real(x) / viewRect.width() - 0.5 ),
+                               logicalRect.height() * ( 0.5 - real(y) / viewRect.height() ), 0);
 }
 
 
@@ -76,7 +75,7 @@ CPoint3d CSailDisp::screenToLogical( const int x, const int y ) const
 void CSailDisp::setAngle( real azimuth, real elevation )
 {
     m = CMatrix::rot3d(0, PI/180*elevation) * CMatrix::rot3d(1, PI/180*azimuth);
-    calcSailDisp();
+    calcDispObject();
 }
 
 
@@ -87,29 +86,36 @@ void CSailDisp::setAngle( real azimuth, real elevation )
 void CSailDisp::setCenter( CPoint3d newCenter )
 {
     center = newCenter;
-    m_lRect = calcLRect(m_vRect, rectBase);
+    logicalRect = calcLRect(viewRect, baseRect);
 }
 
 
-/** Sets the sail that is to be displayed.
- *  and center it.
+/** Sets the object that is to be displayed
+ *  and center the view.
  */
-void CSailDisp::setSail( const CSail &sail )
+void CSailDisp::setObject( const CPanelGroup &obj )
 {
-    sailBase = sail + CVector3d( -sail.boundingRect().center() );
-    rectBase = sailBase.boundingRect();
-    calcSailDisp();
-    m_lRect = calcLRect(m_vRect, rectBase);
+    baseObject = obj;
+    baseRect = baseObject.boundingRect();
+
+    // handle case where the bounding rectangle is flat
+    if (baseRect.height() == 0)
+        baseRect.max.y() += 1;
+    if (baseRect.width() == 0)
+        baseRect.max.x() += 1;
+    center = baseRect.center();
+
+    calcDispObject();
+    logicalRect = calcLRect(viewRect, baseRect);
 }
 
 
 /** Set the size of the viewing rectangle.
  */
-void CSailDisp::setVRect(const int width, const int height)
+void CSailDisp::setViewRect( const CRect3d &rect )
 {
-    m_vRect.min=CPoint3d(0,0,0);
-    m_vRect.max=CPoint3d(width,height);
-    m_lRect = calcLRect(m_vRect, rectBase);
+    viewRect = rect;
+    logicalRect = calcLRect(viewRect, baseRect);
 }
 
 
@@ -120,9 +126,10 @@ void CSailDisp::setVRect(const int width, const int height)
 void CSailDisp::setZoom(real newZoom)
 {
     zoom = newZoom;
-    m_lRect = calcLRect(m_vRect, rectBase);
+    logicalRect = calcLRect(viewRect, baseRect);
 }
 
+
 /** Zooms IN by a factor 2.
  */
 void CSailDisp::zoomIn()
