@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,12 +20,12 @@
 #ifndef SAILDISP_H
 #define SAILDISP_H
 
-#include "sail.h"
-#include "geocpp/matrix.h"
+#include "panelgroup.h"
+#include <geocpp/geocpp.h>
 #include "disparea.h"
 
 
-/** A generic display area for a sail.
+/** A generic display area for a panel group.
  *
  * @see CSailDispLabel
  * @see CSailDispGL
@@ -40,15 +40,10 @@ public:
     {}
     ;
 
-    /** Accessor for the sail. */
-    virtual const CSail& getSail()
-    {
-        return sailBase;
-    };
     /** Acessor for the logical viewport rectangle */
-    virtual const CRect3d& getLRect()
+    virtual const CRect3d& getLogicalRect() const
     {
-        return m_lRect;
+        return logicalRect;
     };
 
     /** Redraw the view. */
@@ -59,8 +54,8 @@ public:
     virtual CPoint3d screenToLogical( const int x, const int y ) const;
     virtual void setAngle( real azimuth, real elevation );
     virtual void setCenter( CPoint3d newCenter );
-    virtual void setSail( const CSail &sail );
-    virtual void setVRect(const int width, const int height);
+    virtual void setObject( const CPanelGroup &objs );
+    virtual void setViewRect( const CRect3d &rect );
     virtual void setZoom(real newZoom);
     virtual void zoomIn();
     virtual void zoomOut();
@@ -69,22 +64,23 @@ public:
     bool drawLabels;
 
 private:
-    virtual void calcSailDisp();
+    void calcDispObject();
 
 protected:
-    // member variables
+    /** Rotated copy of the objects */
+    CPanelGroup dispObject;
+
+private:    
     /** Rotation matrix for the view */
     CMatrix m;
-    /** Unrotated copy of the sail */
-    CSail sailBase;
-    /** Rotated copy of the sail */
-    CSail sailDisp;
     /** Viewport rectangle, in logical coordinates */
-    CRect3d m_lRect;
+    CRect3d logicalRect;
     /** Viewport rectangle, in device coordinates */
-    CRect3d m_vRect;
-    /** Bounding rectangle of the unrotated sail */
-    CRect3d rectBase;
+    CRect3d viewRect;
+    /** Bounding rectangle of the unrotated object */
+    CRect3d baseRect;
+    /** Unrotated copy of the object */
+    CPanelGroup baseObject;
 };
 
 
