@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,7 @@
   #include "config.h"
 #endif
 
-#ifdef HAVE_GL
+#ifdef HAVE_QTOPENGL
 
 #include "saildispgl.h"
 #include <QMouseEvent>
@@ -91,21 +91,30 @@ void CSailDispGL::draw( const CPanel &panel )
  *
  * @param sail
  */
-void CSailDispGL::draw( const CSail &sail )
+void CSailDispGL::draw( const CPanelGroup &sail )
 {
-    for( unsigned int i = 0; i < sail.nbpanels(); i++ )
+    unsigned int i;
+    for( i = 0; i < sail.panel.size(); i++ )
     {
-        if ( i < sail.nbpanels()-1 )
-        {   // alternate light yellow / yellow panels
-            glColor3f(.9, .9, 0.4 + 0.4*(i % 2));
+        if ( sail.type == HULL )
+        {
+            //  dark green
+            glColor3f(.1, .3, .2);
+        } 
+        else if ( sail.type == RIG )
+        {
+            //  dark red
+            glColor3f(.5, .1, .1);
         }
         else
-        {   //  grey
-            glColor3f(.4, .5, .5);
+        {
+            // sail color alternate dark yellow / yellow panels / white
+            glColor3f( .8, .7 + 0.05*(i % 3), 0.4 + 0.2*(i % 3));
         }
-
         draw( sail.panel[i] );
     }
+    for( i = 0; i < sail.child.size(); i++ )
+        draw( sail.child[i] );
 }
 
 
@@ -163,14 +172,21 @@ void CSailDispGL::paintGL()
 {
     clear();
 
+    if ( wasResized )
+    {
+        glViewport( 0, 0, (GLint)resizeW, (GLint)resizeH );
+        setViewRect( CRect3d(CPoint3d(0,0,0), CPoint3d(resizeW,resizeH,0)) );
+        wasResized = 0;
+    }
+    
     // set coordinate system to match the logical viewport
     glLoadIdentity();
-    CRect3d lRect = getLRect();
+    CRect3d lRect = getLogicalRect();
     real zs = real(2) / sqrt(lRect.width()*lRect.width() + lRect.height()*lRect.height());
     glScaled(real(2) / lRect.width(),real(2) / lRect.height(),zs);
     glTranslated(-center.x(),-center.y(),-center.z());
 
-    draw( sailDisp );
+    draw( dispObject );
 }
 
 
@@ -181,8 +197,9 @@ void CSailDispGL::paintGL()
  */
 void CSailDispGL::resizeGL( int w, int h )
 {
-    glViewport( 0, 0, (GLint)w, (GLint)h );
-    setVRect(w,h);
+    resizeW = w;
+    resizeH = h;
+    wasResized = 1;
 }
 
 
