@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -38,12 +38,17 @@ public:
 protected:
     void clear();
     void draw( const CPanel &panel );
-    void draw( const CSail &sail );
+    void draw( const CPanelGroup &sail );
     void initializeGL();
     void mousePressEvent ( QMouseEvent * );
     void paintGL();
     void resizeGL( int w, int h );
     void wheelEvent( QWheelEvent *event);
+
+    /** width of last resize event */
+    int resizeW;
+    /** height of last resize event */
+    int resizeH;
 };
 
 
