@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -65,20 +65,21 @@ void CSailDispLabel::paintEvent( QPaintEvent * )
     // check if the window was resized since last redraw
     if ( wasResized )
     {
-        setVRect(rect.width(), rect.height());
+        setViewRect(painter.viewRect());
+        wasResized = 0;
     }
 
     // set coordinate system to match the logical viewport
-    painter.setWindow(getLRect());
+    painter.setWindow(getLogicalRect());
     painter.setFontSize(10, zoom);
 
     // draw the sail
-    painter.draw(sailDisp);
+    painter.draw(dispObject);
 
     // optionally draw labels
     if (drawLabels)
     {
-        painter.drawLabels(sailDisp);
+        painter.drawLabels(dispObject);
     }
     painter.end();
 }
