@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,10 +20,6 @@
 #ifndef SAILDISPLABEL_H
 #define SAILDISPLABEL_H
 
-#ifdef HAVE_CONFIG_H
-  #include "config.h"
-#endif
-
 #include <QLabel>
 #include "saildisp.h"
 
