@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -21,9 +21,11 @@
 #define SAILDOC_H
 
 #include <QDomDocument>
-#include "sail.h"
-#include "saildef.h"
+#include "panelgroup.h"
+#include "boatdef.h"
+#include "hulldef.h"
 #include "rigdef.h"
+#include "saildef.h"
 #include "prefs.h"
 
 /** This class handles input and output to Sailcut XML documents.
@@ -46,18 +48,24 @@ public:
     // input
     void get
         (const QDomNode &parent, int &i, const QString &name );
+    void get
+        (const QDomNode &parent, unsigned int &i, const QString &name );
     void get
         (const QDomNode &parent, real &r, const QString &name );
     void get
         (const QDomNode &parent, QString &s, const QString &name );
     void get
         (const QDomNode &parent, CPoint3d &p, const QString &name );
+    void get
+        (const QDomNode &parent, enumBoatElementType &t, const QString &name );
+    void get
+        (const QDomNode &parent, enumPanelGroupType &t, const QString &name );
     void get
         (const QDomNode &parent, enumSailCut &c, const QString &name );
     void get
         (const QDomNode &parent, enumSailType &t, const QString &name );
     void get
-        (const QDomNode &parent, enumRigSailType &t, const QString &name );
+        (const QDomNode &parent, CHullDef &d, const QString &name );
     void get
         (const QDomNode &parent, CSailDef &d, const QString &name );
     void get
@@ -65,17 +73,19 @@ public:
     void get
         (const QDomNode &parent, CPanel &p, const QString &name );
     void get
-        (const QDomNode &parent, CRigDef &d, const QString &name );
+        (const QDomNode &parent, CBoatDef &d, const QString &name );
     void get
-        (const QDomNode &parent, CRigSail &s, const QString &name );
+        (const QDomNode &parent, CBoatElement &s, const QString &name );
     void get
-        (const QDomNode &parent, CSail &s, const QString &name );
+        (const QDomNode &parent, CPanelGroup &g, const QString &name );
     void get
         (const QDomNode &parent, CProfile &p, const QString &name );
     void get
         (const QDomNode &parent, CSailMould &m, const QString &name );
     void get
         (const QDomNode &parent, CPrefs &p, const QString &name );
+    void get
+        (const QDomNode &parent, CRigDef &d, const QString &name );
 
     /** Reads a vector of elements from an XML document.
      *
@@ -103,21 +113,25 @@ public:
 
     // output
     void put(QDomNode &parent, const int &i, const QString &name ="" );
+    void put(QDomNode &parent, const unsigned int &i, const QString &name ="" );
     void put(QDomNode &parent, const real &r, const QString &name ="" );
     void put(QDomNode &parent, const QString &s, const QString &name="" );
     void put(QDomNode &parent, const CPoint3d &p, const QString &name="" );
-    void put(QDomNode &parent, const enumRigSailType &t, const QString &name="");
+    void put(QDomNode &parent, const enumBoatElementType &t, const QString &name="");
+    void put(QDomNode &parent, const enumPanelGroupType &t, const QString &name="" );
     void put(QDomNode &parent, const enumSailCut &c, const QString &name="" );
     void put(QDomNode &parent, const enumSailType &t, const QString &name="" );
-    void put(QDomNode &parent, const CRigDef &d, const QString &name="" );
-    void put(QDomNode &parent, const CRigSail &s, const QString &name="" );
+    void put(QDomNode &parent, const CBoatDef &d, const QString &name="" );
+    void put(QDomNode &parent, const CBoatElement &s, const QString &name="" );
+    void put(QDomNode &parent, const CHullDef &d, const QString &name="" );
     void put(QDomNode &parent, const CSailDef &d, const QString &name="" );
     void put(QDomNode &parent, const CSide &s, const QString &name="" );
     void put(QDomNode &parent, const CPanel &p, const QString &name="" );
-    void put(QDomNode &parent, const CSail &s, const QString &name="" );
+    void put(QDomNode &parent, const CPanelGroup &g, const QString &name="" );
     void put(QDomNode &parent, const CProfile &p, const QString &name="" );
     void put(QDomNode &parent, const CSailMould &m, const QString &name="" );
     void put(QDomNode &parent, const CPrefs &p, const QString &name="" );
+    void put(QDomNode &parent, const CRigDef &d, const QString &name="" );
 
     /** Writes a vector of elements to an XML document.
      *
