@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -308,24 +308,33 @@ CProfile CSailMould::interpol ( const real h ) const
         cout << "profile < 3 !!" << endl;
 
     CProfile p;
-    real pv=real(vertpos)/100;
+    real pv = real(vertpos) / 100;
+    real dpth = 0;
     real hr;
 
-    if ( h <= 0 )   // below clew
+    if ( h <= 0 )   // at or below lower profile
     {
-        p = profile[0];
+        /*p = profile[0];*/
+        hr = h / pv;
+        dpth = profile[0].getDepth() + (profile[1].getDepth()-profile[0].getDepth()) * hr;
+        if ( dpth < 0 ) dpth = 0;
+        p = CProfile( dpth, profile[0].getLeech() , profile[0].getLuff() );
     }
-    else if (h < pv)   // below max depth
+    else if ( h < pv )   // below max depth
     {
-        hr = h /pv;
-        p = CProfile( profile[0].getDepth() + (profile[1].getDepth()-profile[0].getDepth()) * (1-(1-hr)*(1-hr)),
+        hr = h / pv;
+        dpth = profile[0].getDepth() + (profile[1].getDepth()-profile[0].getDepth()) * (1-(1-hr)*(1-hr));
+        if ( dpth < 0 ) dpth = 0;
+        p = CProfile( dpth ,
                       profile[0].getLeech() + (profile[1].getLeech()-profile[0].getLeech()) * hr,
                       profile[0].getLuff()  + (profile[1].getLuff()-profile[0].getLuff()) * hr );
     }
     else if ( h < 1 )   // above max depth and below peak
     {
-        hr = (h-pv)/(1-pv);
-        p = CProfile( profile[1].getDepth() + (profile[2].getDepth()-profile[1].getDepth()) * hr*hr,
+        hr = (h-pv) / (1-pv);
+        dpth = profile[1].getDepth() + (profile[2].getDepth()-profile[1].getDepth()) * hr*hr;
+        if ( dpth < 0 ) dpth = 0;
+        p = CProfile( dpth ,
                       profile[1].getLeech() + (profile[2].getLeech()-profile[1].getLeech()) * hr,
                       profile[1].getLuff()  + (profile[2].getLuff()-profile[1].getLuff()) * hr );
     }
