@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  */
 
 #include "sailpainter.h"
-#include "sail.h"
+#include "panelgroup.h"
 
 /** Draws a side of a sail.
  */
@@ -43,7 +43,7 @@ void CSailPainter::draw(const CSide &side)
  */
 void CSailPainter::draw(const CPanel &panel)
 {
-    setPen(Qt::blue);
+    //setPen(Qt::blue);
     draw(panel.left);
     draw(panel.right);
     draw(panel.top);
@@ -52,12 +52,14 @@ void CSailPainter::draw(const CPanel &panel)
     if (panel.hasHems)
     {
         setPen(Qt::red);
+        
         draw(panel.cutLeft);
         draw(panel.cutRight);
         draw(panel.cutTop);
-        draw(panel.cutBottom);
+        draw(panel.cutBottom); 
+        // reset pen color
+        setPen(Qt::black);
     }
-    setPen(Qt::black);
 }
 
 
@@ -65,20 +67,39 @@ void CSailPainter::draw(const CPanel &panel)
  */
 void CSailPainter::draw(const CPanelLabel &label)
 {
+    setPen(Qt::black);
+    
     drawTextCentered(label.origin, QStringList(label.name));
 }
 
 
 /** Draws a complete sail.
  */
-void CSailPainter::draw(const CSail &sail)
+void CSailPainter::draw(const CPanelGroup &sail)
 {
-    for( unsigned int i = 0; i < sail.nbpanels(); i++ )
+    unsigned int i;
+    
+    for( i = 0; i < sail.panel.size(); i++ )
+    {   
+        if ( sail.type == HULL )
+            setPen(Qt::darkGreen);
+        else if ( sail.type == RIG )
+            setPen(Qt::darkRed);
+        else
+            setPen(Qt::blue);
+             
         draw(sail.panel[i]);
+    }
+    for( i = 0; i < sail.child.size(); i++ )
+        draw(sail.child[i]);
+        
+    // reset pen color 
+    setPen(Qt::black);
+        
 }
 
 
-/** Draws a complete sail.
+/** Draws a cross at a given Point position.
  */
 void CSailPainter::drawCross(const CPoint3d &p, const real size)
 {
@@ -91,6 +112,7 @@ void CSailPainter::drawCross(const CPoint3d &p, const real size)
  */
 void CSailPainter::drawTextCentered(const CPoint3d &p, const QString &str)
 {
+    setPen(Qt::black);
     drawTextCentered(p, QStringList(str));
 }
 
@@ -100,6 +122,7 @@ void CSailPainter::drawTextCentered(const CPoint3d &p, const QString &str)
 void CSailPainter::drawTextCentered(const CPoint3d &p, const QStringList &lst)
 {
     CVector3d dim = textSize(lst);
+    setPen(Qt::black);
 
     int i;
     real xPos = p.x() - 0.5 * dim.x();
@@ -115,10 +138,15 @@ void CSailPainter::drawTextCentered(const CPoint3d &p, const QStringList &lst)
 
 /** Draw all the sail's panel labels.
  */
-void CSailPainter::drawLabels(const CSail &sail)
+void CSailPainter::drawLabels(const CPanelGroup &sail)
 {
-    for ( unsigned int i = 0; i < sail.nbpanels(); i++ )
+    unsigned int i;
+    setPen(Qt::black);
+    
+    for ( i = 0; i < sail.panel.size(); i++ )
         draw(sail.panel[i].label);
+    for ( i = 0; i < sail.child.size(); i++ )
+        drawLabels(sail.child[i]);
 }
 
 
@@ -168,3 +196,13 @@ CVector3d CSailPainter::textSize(const QStringList &lst)
 
     return v;
 }
+
+
+/** Return the viewport rectangle.
+ */
+CRect3d CSailPainter::viewRect() const
+{
+    return CRect3d(CPoint3d(0,0,0), CPoint3d(viewport().width(), viewport().height()));
+}
+
+
