@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,12 +21,12 @@
 #define SAILPAINTER_H
 
 #include <QPainter>
-#include "geocpp/geometry.h"
+#include <geocpp/geocpp.h>
 
-class CSail;
 class CSide;
 class CPanel;
 class CPanelLabel;
+class CPanelGroup;
 
 /** A sail painter
  *
@@ -40,21 +40,22 @@ public:
      * @param dev the paint device we are operating on
     */
     CSailPainter(QPaintDevice *dev) : QPainter(dev)
-    {}
-    ;
+    {};
 
     void draw(const CSide &side);
     void draw(const CPanel &panel);
-    void draw(const CSail &sail);
+    void draw(const CPanelGroup &sail);
     void draw(const CPanelLabel &label);
     void drawCross(const CPoint3d &p, const real size);
     void drawTextCentered(const CPoint3d &p, const QString &str);
     void drawTextCentered(const CPoint3d &p, const QStringList &lst);
-    void drawLabels(const CSail &sail);
+    void drawLabels(const CPanelGroup &sail);
 
     void setFontSize(const real size, const real zoom);
     void setWindow(const CRect3d& lRect);
+
     CVector3d textSize(const QStringList &lst);
+    CRect3d viewRect() const;
 };
 
 #endif
