@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -18,7 +18,7 @@
  */
 
 #include "sailviewer-panel.h"
-#include "sail.h"
+#include "panelgroup.h"
 
 #include <QGroupBox>
 #include <QLabel>
@@ -150,13 +150,13 @@ void CSailViewerPanel::languageChange()
 
 
 /**
- * Change the sail to be displayed.
+ * Change the displayed object.
  *
- * @param sail The new sail
+ * @param obj the new object to display
  */
-void CSailViewerPanel::setSail(const CSail& sail)
+void CSailViewerPanel::setObject(const CPanelGroup &obj)
 {
-    sailDisp->setSail(sail);
+    sailDisp->setObject(obj);
 }
 
 
