@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -37,7 +37,7 @@ class CSailViewerPanel : public QWidget
 public:
     CSailViewerPanel(QWidget *parent, const enumViewMode viewMode, bool show_sliders, bool show_labeling = true);
 
-    void setSail(const CSail& sail);
+    void setObject(const CPanelGroup &obj);
     void keyPressEvent ( QKeyEvent * e );
 
     // slots
