@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 
 #include "sailviewer.h"
 #include "saildisplabel.h"
-#ifdef HAVE_GL
+#ifdef HAVE_QTOPENGL
   #include "saildispgl.h"
 #endif
 #include <QSlider>
@@ -66,7 +66,7 @@ CSailViewer::CSailViewer( QWidget *parent, enumViewMode viewMode, bool show_slid
     /* create the drawing area */
     switch (viewMode)
     {
-#ifdef HAVE_GL
+#ifdef HAVE_QTOPENGL
     case SHADED:
         lblDraw = new CSailDispGL( this );
         sailDispLayout->addWidget( (CSailDispGL*)(lblDraw), 0, xpos );
@@ -109,13 +109,13 @@ void CSailViewer::keyPressEvent ( QKeyEvent * e )
 }
 
 
-/** Changes the current sail.
+/** Changes the displayed object.
  *
- * @param sail the new sail to be displayed
+ * @param obj the new object to be displayed
  */
-void CSailViewer::setSail(const CSail& sail)
+void CSailViewer::setObject(const CPanelGroup &obj)
 {
-    lblDraw->setSail(sail);
+    lblDraw->setObject(obj);
     lblDraw->redraw();
 }
 
