@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -21,11 +21,11 @@
 #define SAILVIEWER_H
 
 #include <QWidget>
-#include "geocpp/core.h"
+#include "panelgroup.h"
 
 class QSlider;
 class QLabel;
-class CSail;
+class CPanelGroup;
 class CSailDisp;
 class QGridLayout;
 
@@ -42,7 +42,7 @@ class CSailViewer : public QWidget
 public:
     CSailViewer(QWidget *parent, enumViewMode viewMode, bool show_sliders = true);
 
-    void setSail( const CSail &sail );
+    void setObject( const CPanelGroup &obj );
     void keyPressEvent ( QKeyEvent * e );
 
 protected slots:
