@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,21 +20,19 @@
 #ifndef SAILWORKER_H
 #define SAILWORKER_H
 
-#include "sail.h"
+#include "panelgroup.h"
 #include "saildef.h"
 
-#include "geocpp/geometry.h"
-#include "sailcalc.h"
-
 // forward declarations
-class CSail;
+class CPanelGroup;
 class CSeam;
 
+enum enumEdgeType { LUFF_EDGE, GAFF_EDGE, FOOT_EDGE, LEECH_EDGE };
 
-/** The CSailWorker class does all the sail-related calculations. It is used to create
- * the sail from its definition.
+/** The CSailWorker class does all the sail-related calculations like laying the panels
+ *  It is used to create the sail from its definition.
  *
- * @see CSailDef, CSail
+ * @see CSailDef, CPanelGroup
  */
 class CSailWorker : public CSailDef
 {
@@ -44,15 +42,13 @@ public:
     real Area();
     real Diagonal();
     real IRCwidth( const real &h );
-    real SailW( const real &h );
+    real SailWidth( const real &h );
     real LeechLength( const real &h );
     real LuffLength( const real &h );
     real SailLP( );
 
-    // create a panel representing the deck
-    CPanel makeDeck() const;
-    CSail makeSail() const;
-    CSail makeSail(CSail &flatsail, CSail &dispsail) const;
+    CPanelGroup makeSail() const;
+    CPanelGroup makeSail(CPanelGroup &flatsail, CPanelGroup &dispsail) const;
 
     /** position of tack point */
     CPoint3d tack;
@@ -64,25 +60,26 @@ public:
     CPoint3d clew;
 
 protected:
+    /** type of Edge of sail */
+    enumEdgeType Edge;
+    
     /** layout of sail's panels */
-    CSail Layout0( CSail &flatsail, CSail &dispsail ) const; // CROSS
-    CSail LayoutTwist( CSail &flatsail, CSail &dispsail ) const; // TWIST
-    CSail LayoutVertical( CSail &flatsail, CSail &dispsail ) const; // VERTICAL
-    CSail LayoutRadial( CSail &flatsail, CSail &dispsail ) const;// RADIAL
-    CSail LayoutMitre( CSail &flatsail, CSail &dispsail ) const; // MITRE
-    CSail LayoutTriRadial( CSail &flatsail, CSail &dispsail ) const; // TRIRADIAL
-    CSail LayoutWing( CSail &flatsail, CSail &dispsail ) const; // WING
+    CPanelGroup Layout0( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // CROSS
+    CPanelGroup LayoutTwist( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // TWIST
+    CPanelGroup LayoutVertical( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // VERTICAL
+    CPanelGroup LayoutRadial( CPanelGroup &flatsail, CPanelGroup &dispsail ) const;// RADIAL
+    CPanelGroup LayoutMitre( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // MITRE
+    CPanelGroup LayoutTriRadial( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // TRIRADIAL
+    CPanelGroup LayoutWing( CPanelGroup &flatsail, CPanelGroup &dispsail ) const; // WING
 
     /** intersections with edges */
-    CPoint3d FwdIntersect( const CPoint3d &p1 ) const;
-    CPoint3d AftIntersect( const CPoint3d &p1 ) const;
-    CPoint3d FootIntersect( const CPoint3d &pt1, const CVector3d &v1 ) const;
-    CPoint3d GaffIntersect( const CPoint3d &pt1, const CVector3d &v1 ) const;
-    CPoint3d LeechIntersect( const CPoint3d &pt1, const CVector3d &v1 ) const;
-    CPoint3d LuffIntersect( const CPoint3d &pt1, const CVector3d &v1 ) const;
+    CPoint3d EdgeIntersect( const enumEdgeType &Edge, const CPoint3d &pt1, const CVector3d &v1 ) const;
+    CPoint3d FwdIntersect( const CPoint3d &pt1 ) const;
+    CPoint3d AftIntersect( const CPoint3d &pt1 ) const;
     CPoint3d MitreIntersect( const CPoint3d &pt1, const CVector3d &v1 ) const;
+    
     /** mitre intersection point with luff */
-    CPoint3d mitrePt;
+    CPoint3d mitreLuffPt;
     
     /** depth at any point */
     CPoint3d Zpoint( const CPoint3d &p1 ) const;
@@ -107,15 +104,15 @@ protected:
     CVector3d mitreV;
     
     /** 3D foot straight line */
-    CSubSpace foot;
+    CSubSpace footLine;
     /** 3D gaff straight line */
-    CSubSpace gaff;
+    CSubSpace gaffLine;
     /** 3D leech straight line */
-    CSubSpace leech;
+    CSubSpace leechLine;
     /** 3D luff straight line */
-    CSubSpace luff;
+    CSubSpace luffLine;
     /** 3D mitre straight line */
-    CSubSpace mitre;
+    CSubSpace mitreLine;
 };
 
 #endif
