@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -21,29 +21,22 @@
 #define SAILWRITER_CARLSON_H
 
 #include "filewriter.h"
-#include "sail.h"
+#include "panelgroup.h"
 #include <fstream>
 
 /** A class for writing to Carlson files.
  */
-class CSailCarlsonWriter : public CFileWriter
+class CSailCarlsonWriter : public CFileWriter<CPanelGroup>
 {
-protected:
-    /** the sail we want to write to a file. */
-    CSail _sail;
-    /** the output stream */
-    ofstream _myOut;
-
 public:
-    CSailCarlsonWriter(const CSail &sail);
+    CSailCarlsonWriter();
 
-    void write(const QString &filename);
-    void writePanel(unsigned int panel);
-    void writePanelHeader (unsigned int panel);
-    void writeDraw(unsigned int ct);
-    void writeCut(unsigned int ct);
-    void writePoint(CPoint3d p0);
-    void writeEOF();
+    void write(const CPanelGroup &sail, const QString &filename) const;
+    void writePanel(ofstream &out, const CPanel &panel) const;
+    void writePanelHeader(ofstream &out, const CPanel &panel) const;
+    void writeDraw(ofstream &out, unsigned int ct) const;
+    void writeCut(ofstream &out, unsigned int ct) const;
+    void writePoint(ofstream &out, CPoint3d p0) const;
 
 };
 
