@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,39 +21,29 @@
 #define SAILWRITER_DXF_H
 
 #include "filewriter.h"
-#include "sail.h"
+#include "panelgroup.h"
 #include <iostream>
 #include <fstream>
 
 /** An abstract class containing the methods needed for DXF writing.
  */
-class CSailDxfWriter : public CFileWriter
+class CSailDxfWriter : public CFileWriter<CPanelGroup>
 {
-protected:
-    /** the sail to write */
-    CSail _sail;
-    /** the output stream */
-    ofstream _out;
-
 public:
     /** The constructor.
-     *
-     * @param sail the sail to write
      */
-    CSailDxfWriter(const CSail &sail)
-            : CFileWriter(".dxf", "DXF files"), _sail(sail)
+    CSailDxfWriter() : CFileWriter<CPanelGroup>(".dxf", "DXF files")
     {}
     ;
 
-    void writeAtom(int code, const QString& content);
-    void writeFace(CPoint3d p0, CPoint3d p1, CPoint3d p2, unsigned int layer);
-    void writePolyline( unsigned int layer, unsigned int color);
-    void writeVertex(CPoint3d p0, unsigned int layer);
-
+    void writeAtom(ofstream &out, int code, const QString& content) const;
+    void writeFace(ofstream &out, CPoint3d p0, CPoint3d p1, CPoint3d p2, unsigned int layer) const;
+    void writePolyline(ofstream &out, unsigned int layer, unsigned int color) const;
+    void writeVertex(ofstream &out, CPoint3d p0, unsigned int layer) const;
 };
 
 
-/** A class used to write a CSail to a simple 2D DXF file.
+/** A class used to write a CPanelGroup to a simple 2D DXF file.
  */
 class CSailDxfWriter2d : public CSailDxfWriter
 {
@@ -62,51 +52,44 @@ public:
      *
      * @param sail the sail to write
      */
-    CSailDxfWriter2d(const CSail &sail)
-            : CSailDxfWriter(sail)
+    CSailDxfWriter2d() : CSailDxfWriter()
     {}
     ;
 
-    void write(const QString &filename);
-    void writePanel(unsigned int panel);
+    void write(const CPanelGroup &sail, const QString &filename) const;
+    void writePanel(ofstream &out, const CPanel &panel, unsigned int layer) const;
 };
 
 
-/** A class used to write a CSail to a 2D DXF file with one block per panel.
+/** A class used to write a CPanelGroup to a 2D DXF file with one block per panel.
  */
 class CSailDxfWriter2dBlocks : public CSailDxfWriter2d
 {
 public:
     /** The constructor.
-     *
-     * @param sail the sail to write
      */
-    CSailDxfWriter2dBlocks(const CSail &sail)
-            : CSailDxfWriter2d(sail)
+    CSailDxfWriter2dBlocks() : CSailDxfWriter2d()
     {}
     ;
 
-    void write(const QString &filename);
+    void write(const CPanelGroup &sail, const QString &filename) const;
 };
 
 
 
-/** A class used to write a CSail to a 3D DXF file.
+/** A class used to write a CPanelGroup to a 3D DXF file.
  */
 class CSailDxfWriter3d : public CSailDxfWriter
 {
 public:
     /** The constructor.
-     *
-     * @param sail the sail to write
      */
-    CSailDxfWriter3d(const CSail &sail)
-            : CSailDxfWriter(sail)
+    CSailDxfWriter3d() : CSailDxfWriter()
     {}
     ;
 
-    void write(const QString &filename);
-    void writePanel(unsigned int panel);
+    void write(const CPanelGroup &sail, const QString &filename) const;
+    void writePanel(ofstream &out, const CPanel &panel, unsigned int layer) const;
 };
 
 
