@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,6 @@
 #ifndef SAILWRITER_HAND_H
 #define SAILWRITER_HAND_H
 
-#include "sail.h"
 #include "sailwriter-txt.h"
 
 /** This class allows you to write a developed sail by using
@@ -34,12 +33,11 @@ public:
      *
      * @param sail the sail to write
      */
-    CSailHandWriter(const CSail &sail)
-            : CSailTxtWriter(sail)
+    CSailHandWriter() : CSailTxtWriter()
     {}
     ;
 
-    virtual void write(const QString &filename);
+    virtual void write(const CPanelGroup &sail, const QString &filename) const;
 };
 
 
