@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -26,14 +26,14 @@
  *
  * @param filename the file to write to
  */
-void CSailTxtWriter::write(const QString &filename)
+void CSailTxtWriter::write(const CPanelGroup &sail, const QString &filename) const
 {
     ofstream myOut;
     myOut.open(QFile::encodeName(filename), ios::out);
     if (!myOut.is_open())
         throw CException("CSailTxtWriter::write : unable to write to specified file");
-    myOut << string(_sail.sailID.toLocal8Bit()) << endl;
-    myOut << _sail;
+    myOut << string(sail.title.toLocal8Bit()) << endl;
+    myOut << sail;
     myOut.close();
 }
 
