@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -21,28 +21,21 @@
 #define TXTWRITER_H
 
 #include "filewriter.h"
-#include "sail.h"
+#include "panelgroup.h"
 
 
-/** A class used to output a CSail to a TXT file.
+/** A class used to output a CPanelGroup to a TXT file.
  */
-class CSailTxtWriter : public CFileWriter
+class CSailTxtWriter : public CFileWriter<CPanelGroup>
 {
-protected :
-    /** the sail to write */
-    CSail _sail;
-
 public:
     /** The constructor.
-     *
-     * @param sail the sail to write
      */
-    CSailTxtWriter(const CSail &sail)
-            : CFileWriter(".txt","Text files"), _sail(sail)
+    CSailTxtWriter() : CFileWriter<CPanelGroup>(".txt","Text files")
     {}
     ;
 
-    virtual void write(const QString &filename);
+    virtual void write(const CPanelGroup &sail, const QString &filename) const;
 };
 
 
