@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1993-2006 Robert & Jeremy Laine
+ * Copyright (C) 1993-2007 Robert & Jeremy Laine
  * See AUTHORS file for a full list of contributors.
  * 
  * This program is free software; you can redistribute it and/or modify
@@ -21,96 +21,138 @@
 #define SAILWRITER_XML_H
 
 #include "filewriter.h"
+#include "saildoc.h"
+
 
 /** This class allows you to write sailcut objects to
  *  an XML file.
  *
- *  @see CSailXmlWriter
+ *  @see CPanelGroupXmlWriter
  *  @see CSailDefXmlWriter
  */
 template <class objtype>
-class XmlWriterTempl : public CFileWriter
+class XmlWriterTempl : public CFileWriter<objtype>
 {
 protected :
     /** the object's name */
     QString _name;
-    /** the object to write */
-    objtype _obj;
 
 public:
     /** The constructor.
      *
-     * @param obj the object to write
      * @param name the object's name
      * @param ext the file extension to show (defaults to ".xml")
      * @param desc a description of the file type (defaults to "XML files")
      */
-    XmlWriterTempl(const objtype &obj, const QString &name,
-                   const QString ext = ".xml", const QString desc = "XML files")
-            : CFileWriter(ext, desc), _name(name), _obj(obj)
+    XmlWriterTempl(const QString &name,
+                   const QString ext = ".xml",
+                   const QString desc = "XML files")
+            : CFileWriter<objtype>(ext, desc), _name(name)
     {}
     ;
 
     /** Write object to XML format.
      *
+     * @param obj the object to write
      * @param filename the file to write to
      */
-    virtual void write(const QString &filename)
+    virtual void write(const objtype &obj, const QString &filename) const
     {
         CSailDoc doc;
-        doc.put(doc.top, _obj, _name);
+        doc.put(doc.top, obj, _name);
         doc.toFile(filename);
     };
+
+    /** Read object from an XML file.
+     *
+     * @param filename the file we read from
+     */
+    const objtype read(const QString &filename) const
+    {
+        CSailDoc doc(filename);
+        objtype obj;
+        doc.get(doc.top, obj, _name);
+        return obj;
+    };
+   
 };
 
 
-/** A class used to output a CSail to an XML file. */
-class CSailXmlWriter : public XmlWriterTempl<CSail>
+/** A class used to output a CPanelGroup to an XML file. */
+class CPanelGroupXmlWriter : public XmlWriterTempl<CPanelGroup>
 {
 public:
     /** The constructor.
-     *
-     * @param sail the sail to write
-     * @param name the sail's name
      */
-    CSailXmlWriter(const CSail &sail, const QString &name)
-            : XmlWriterTempl<CSail>(sail, name, ".sail3d", "3D sails")
+    CPanelGroupXmlWriter()
+            : XmlWriterTempl<CPanelGroup>("panelgroup", ".panel3d", "3D sails or hulls")
     {}
     ;
 };
 
+
+/** A class used to output a CHullDef to an XML file. */
+class CHullDefXmlWriter : public XmlWriterTempl<CHullDef>
+{
+public:
+    /** The constructor.
+     */
+    CHullDefXmlWriter()
+            : XmlWriterTempl<CHullDef>("hulldef", ".hulldef", "Hull definitions")
+    {}
+    ;
+};
+
+
 /** A class used to output a CSailDef to an XML file. */
 class CSailDefXmlWriter : public XmlWriterTempl<CSailDef>
 {
 public:
     /** The constructor.
-     *
-     * @param saildef the CSailDef to write
-     * @param name the CSailDef's name
      */
-    CSailDefXmlWriter(const CSailDef &saildef, const QString &name)
-            : XmlWriterTempl<CSailDef>(saildef, name, ".saildef", "Sail definitions")
+    CSailDefXmlWriter()
+            : XmlWriterTempl<CSailDef>("saildef", ".saildef", "Sail definitions")
     {}
     ;
 };
 
+
+/** A class used to output a CBoatDef to an XML file. */
+class CBoatDefXmlWriter : public XmlWriterTempl<CBoatDef>
+{
+public:
+    /** The constructor.
+     */
+    CBoatDefXmlWriter()
+            : XmlWriterTempl<CBoatDef>("boatdef", ".boatdef", "Boat definitions")
+    {}
+    ;
+};
+
+
 /** A class used to output a CRigDef to an XML file. */
 class CRigDefXmlWriter : public XmlWriterTempl<CRigDef>
 {
 public:
     /** The constructor.
-     *
-     * @param rigdef the CRigDef to write
-     * @param name the CRigDef's name
      */
-    CRigDefXmlWriter(const CRigDef &rigdef, const QString &name)
-            : XmlWriterTempl<CRigDef>(rigdef, name, ".sailrig", "Rig definitions")
+    CRigDefXmlWriter()
+            : XmlWriterTempl<CRigDef>("rigdef", ".rigdef", "Rig definitions")
     {}
     ;
 };
 
-/** A class used to output a CPrefs to an XML file. */
-typedef XmlWriterTempl<CPrefs> CPrefsXmlWriter;
 
+/** A class used to output a CPrefs to an XML file. */
+class CPrefsXmlWriter : public XmlWriterTempl<CPrefs>
+{
+public:
+    /** The constructor.
+     */
+    CPrefsXmlWriter()
+            : XmlWriterTempl<CPrefs>("prefs")
+    {}
+    ;
+};
 
 #endif
